Dynatime
========

Information
-----------
Name:
  ``pyplanet.apps.contrib.dynatime``
Depends on:
  ``core.maniaplanet``
Game:
  TrackMania

Features
--------
Dynamically set time limit for each map based on the map's bronze time.

Commands
--------
None.

Signal handlers
---------------

Map begin
~~~~~~~~~
Signal:
  ``pyplanet.apps.core.maniaplanet.callbacks.map.map_begin``
Functionality:
  Updates time limit and announces change to the players.

